import { admin } from '@/access/admin'
import type { CollectionConfig } from 'payload'

import '../envConfig'

const expirationInMinutes = parseInt(process.env.PASSWORD_RESET_EXPIRATION_IN_MINUTES || '30', 10)
const domain = process.env.DOMAIN_NAME || ''
const serverUrl = process.env.SERVER_URL || ''

export const Users: CollectionConfig = {
  slug: 'users',
  admin: {
    useAsTitle: 'email',
  },
  access: {
    admin: admin
  },
  auth: {
    forgotPassword: {
      generateEmailSubject: () => {
        console.log({ domain, serverUrl, expirationInMinutes })
        return `Reset password request for ${domain}`
      },
      generateEmailHTML: (props) => {
        const resetPasswordURL = `${serverUrl}/forgotPassword?token=${props?.token}`

        return `
          <!doctype html>
          <html>
            <body>
              <h1>Reset Password for ${domain}</h1>
              <p>Hello, ${props?.user.firstName}!</p>
              <p>There has been a request for the account account for ${props?.user.email}. If this is not the case then please ignore this email.</p>
              <p>If you intend to reset your password then you can do so with the link below.</p>
              <p>
                <a href="${resetPasswordURL}">${resetPasswordURL}</a>
              </p>
            </body>
          </html>
        `
      },
    }
  },
  fields: [
    // Email added by default
    {
      name: 'role',
      type: 'select',
      options: ['admin', 'user'],
      saveToJWT: true
    },
    {
      name: 'firstName',
      type: 'text',
    },
    {
      name: 'lastName',
      type: 'text',
    },
    {
      name: 'repositories',
      type: 'join',
      collection: 'repositories',
      on: 'owner',
    },
    {
      name: 'profilePicture',
      type: 'relationship',
      relationTo: 'media',
    },
  ],
}
